@@ -1,9 +1,8 @@
 `bestlca` <-
-function(patterns,freq,nclass,calcSE,notrials,probit,penalty,verbose) {
+function(patterns,freq,nclass,calcSE,notrials,probit,penalty,EMtol,verbose) {
 	bics <- rep(NA,notrials)
 	for (i in 1:notrials) {
-		lca <- fitFixed(patterns,freq,nclass=nclass,calcSE=FALSE,justEM=TRUE,probit=probit,penalty=penalty,verbose=verbose)
-		#browser()
+		lca <- fitFixed(patterns,freq,nclass=nclass,calcSE=FALSE,justEM=TRUE,probit=probit,penalty=penalty,EMtol=EMtol,verbose=verbose)
 		currbic <- -2*(lca$logLik)+log(lca$nobs)*lca$np
 		bics[i] <- currbic
 		#browser()
@@ -19,14 +18,14 @@ function(patterns,freq,nclass,calcSE,notrials,probit,penalty,verbose) {
 		if (verbose)
 			cat("iteration ",i,"BIC ",BIC(lca),"\n")
 	}
-		if (verbose) print("refitting to obtain SE")
+	if (verbose) print("refitting to obtain SE")
+	#browser()
 		maxlca <- fitFixed(patterns,freq,nclass=nclass,initoutcomep=maxlca$outcomep,
-			initclassp=maxlca$classp,calcSE=calcSE,justEM=FALSE,probit=probit,penalty=penalty,verbose=verbose)
+			initclassp=maxlca$classp,calcSE=calcSE,justEM=FALSE,probit=probit,penalty=penalty,EMtol=EMtol,verbose=verbose)
 	if (verbose) {
 		print("bic for class")
 		print(bics)
 	}
-	if (sum(abs((maxbic-bics)/maxbic)<1.0e-6)==1) warning("Only one fitted model at maximum loglikelihood. Increase number of trials.")
 	return(c(maxlca,list(bics=bics)))
 }
 
